# Changelog

All notable changes to the genja project are documented in this file. The format is based on [Keep a Changelog](https://keepachangelog.com) and this project adheres to [Calendar Versioning](https://calver.org).

## Genja v22.11

Initial release of the genja command line tool.
